Class: ActiveRecord::Base
- Inherits:
-
Object
- Object
- ActiveRecord::Base
- Defined in:
- lib/seed-fu.rb
Class Method Summary collapse
-
.seed(*constraints, &block) ⇒ Object
Creates a single record of seed data for use with the db:seed rake task.
Class Method Details
.seed(*constraints, &block) ⇒ Object
Creates a single record of seed data for use with the db:seed rake task.
Parameters
- constraints
Immutable reference attributes. Defaults to :id
73 74 75 |
# File 'lib/seed-fu.rb', line 73 def self.seed(*constraints, &block) SeedFu::Seeder.plant(self, *constraints, &block) end |